@@ -90,7 +90,18 @@ void ExerciseWindow::sendClosed()
 
 void ExerciseWindow::loadExercise(QList<QString> name)
 {
-    currentReps = "4";
+    int i = 0;
+    QList <QString> list = xml->getHistoryByExercise(name.first());
+
+    while(!list.isEmpty())
+    {
+        status[i] = list.takeLast();
+        reps[i] = list.takeLast();
+        weight[i] = list.takeLast();
+
+        i++;
+    }
+    currentSet = 0;
 
     bool firstTime = false;
     if(exercises.count() == 0)
@@ -123,7 +134,14 @@ void ExerciseWindow::loadExercise(QList<QString> name)
 
         set = SET; min = MIN; sec = SEC;
         strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
-        label->setText(currentExercise + "\n Shake when done set is done.");
+
+        if(weight[currentSet] != "")
+            label->setText("Exercise: " + currentExercise +  "\nShake when set is done." +
+                           "\nLast time on this set: " + weight[currentSet] + "x"  +
+                           reps[currentSet] + " was " + status[currentSet] + ".");
+        else
+            label->setText("Exercise: " + currentExercise +  "\nShake when set is done.");
+
         btnShake->setEnabled(true);
         myThread->start(QThread::NormalPriority);
     }
@@ -147,12 +165,6 @@ void ExerciseWindow::sendDestroyDialog()
 
 void ExerciseWindow::openED()
 {
-    //QList <QString > tmp, history;
-
-    //for(int i = 0; i < exercises.count(); i++)
-        //history = xml->getHistoryByDate(exercises.at(i));
-
-    //tmp.append(history.at(0) + " (" + history.at(2) + "-" + history.at(3) + ")")
     if(exercises.count() > 1)
     {
         ed = new ExerciseDialog(this);
@@ -165,6 +177,22 @@ void ExerciseWindow::openED()
 
 void ExerciseWindow::setCurrentExercise(QString name)
 {
+    int i = 0;
+    QList <QString> list;
+
+    currentSet = 0;
+
+    list = xml->getHistoryByExercise(name);
+
+    while(!list.isEmpty())
+    {
+        status[i] = list.takeLast();
+        reps[i] = list.takeLast();
+        weight[i] = list.takeLast();
+
+        i++;
+    }
+
     QList <QString> tmp;
     currentExercise = name;
     QDBusMessage reply;
@@ -176,7 +204,13 @@ void ExerciseWindow::setCurrentExercise(QString name)
 
     set = SET; min = MIN; sec = SEC;
     strSet.setNum(SET); strMin.setNum(MIN);  strSec.setNum(SEC);
-    label->setText(currentExercise + "\n Shake when set is done.");
+
+    if(weight[currentSet] != "")
+        label->setText("Exercise: " + currentExercise +  "\nShake when set is done." +
+                       "\nLast time on this set: " + weight[currentSet] + "x"  +
+                       reps[currentSet] + " was " + status[currentSet] + ".");
+    else
+        label->setText("Exercise: " + currentExercise +  "\nShake when set is done.");
 
     btnShake->setEnabled(true);
     myThread->start(QThread::NormalPriority);
@@ -272,7 +306,13 @@ void ExerciseWindow::updateTime()
         {
             //wait is over
 
-            label->setText("Exercise: " + currentExercise +  "\n Shake when set is done.");
+            if(weight[currentSet] != "")
+                label->setText("Exercise: " + currentExercise +  "\nShake when set is done." +
+                               "\nLast time on this set: " + weight[currentSet] + "x"  +
+                               reps[currentSet] + " was " + status[currentSet] + ".");
+            else
+                label->setText("Exercise: " + currentExercise +  "\nShake when set is done.");
+
             btnShake->setEnabled(true);
 
 
@@ -353,6 +393,8 @@ void ExerciseWindow::checkAcc(QString x)
 
 void ExerciseWindow::shaked()
 {
+    currentReps = "4";
+    currentSet++;
     QDBusMessage reply;
     if(set == -1)
         return;
@@ -384,7 +426,7 @@ void ExerciseWindow::shaked()
 
             wd = new WeightDialog(this);
             connect(wd,SIGNAL(next()),this,SLOT(openED()));
-            wd->load(currentExercise, currentGroup, currentReps);
+            wd->load(currentExercise, currentGroup,currentReps);
             wd->show();
             return;
         }
