@@ -76,9 +76,11 @@ private:
     int MIN, SEC, SET;
     int mx, my, mz;
 
-    QString currentExercise,currentGroup;
-    QString strMin,strSec,strSet;
+    QString currentExercise, currentGroup;
+    QString strMin, strSec, strSet;
     QString currentReps;
+    int currentSet;
+    QString weight[9], reps[9], status[9];
 
     QTimer *timer;
     QTimer *tmr;
