@@ -67,7 +67,7 @@ private:
     QGridLayout *gLayout;
     QGridLayout *gButtonLayout;
 
-    //QPixmap *bild;
+    QString weight[9], reps[9], status[9];
 
 private slots:
     void showSettings();
