@@ -99,7 +99,7 @@ void NewExerciseWindow::saveExercise()
     }
     else if(btnGroup->valueText() == "")
     {
-        QMaemo5InformationBox::information(this, "You must choose group.", QMaemo5InformationBox::DefaultTimeout);
+        QMaemo5InformationBox::information(this, "You must choose a group.", QMaemo5InformationBox::DefaultTimeout);
         return;
     }
 
